<?php

/*
Plugin Name: One Click SSL
Plugin URI: https://tribulant.com
Description: SSL redirect and automatic https:// resource conversion for your WordPress website.
Version: 1.4.1
Author: Tribulant Software
Author URI: http://tribulant.com
Text Domain: one-click-ssl
Domain Path: /languages
Network: true
*/

if (!defined('ABSPATH')) exit; // Exit if accessed directly

if (!defined('DS')) { define('DS', DIRECTORY_SEPARATOR); }

if (!class_exists('OCSSL')) {
	
	class OCSSL {
		
		var $plugin_data;
		var $plugin_path;
		var $plugin_url;
		var $plugin_base;
		var $plugin_name;
		var $plugin_version;
		
		// A list of http:// URLs found by build_url_list() method
		var $http_urls = array();
		
		function __construct() {
			require_once(ABSPATH . DS . 'wp-admin' . DS . 'includes' . DS . 'plugin.php');
			
			$this -> plugin_data = get_plugin_data(__FILE__);
			$this -> plugin_path = plugin_dir_path(__FILE__);
			$this -> plugin_url = plugin_dir_url(__FILE__);
			$this -> plugin_base = plugin_basename(__FILE__);
			$this -> plugin_name = dirname($this -> plugin_base);
			$this -> plugin_version = $this -> plugin_data['Version'];
		}
		
		function activation_hook() {
			
			// Add some default settings/options here
			add_option('ocssl', 0);
			add_option('ocssl_areas', "all");
			add_option('ocssl_activation_redirect', true);
			add_option('ocssl_nonsslredirect', 0);
			
			return true;
		}
		
		function init_textdomain() {
			if (function_exists('load_plugin_textdomain')) {
				load_plugin_textdomain($this -> plugin_name, false, dirname(plugin_basename(__FILE__)) . DS . 'languages');
			}
		}
		
		function admin_head() {
			
		}
		
		function custom_redirect() {
			$activation_redirect = get_option('ocssl_activation_redirect');

			if (is_admin() && !empty($activation_redirect)) {
				delete_option('ocssl_activation_redirect');
				wp_cache_flush();
				
				$url = (is_multisite()) ? 
				network_admin_url('index.php?page=one-click-ssl-setup') :
				admin_url('index.php?page=one-click-ssl-setup');
				
				wp_redirect($url);
				exit();
			}
		}
		
		function admin_menu() {
			
			// If this is a multi-site network
			if (is_multisite() && is_network_admin()) {
				$this -> ocssl_menu = add_menu_page(__('One Click SSL', 'one-click-ssl'), __('One Click SSL', 'one-click-ssl'), 'activate_plugins', 'one-click-ssl', array($this, 'admin_network'), null, null);
			} else {
				$ocssl_toolsmenu = get_option('ocssl_toolsmenu');
				if (!empty($ocssl_toolsmenu)) {
					$this -> ocssl_menu = add_management_page(__('One Click SSL', 'one-click-ssl'), __('One Click SSL', 'one-click-ssl'), 'activate_plugins', 'one-click-ssl', array($this, 'admin'));
				} else {
					$this -> ocssl_menu = add_menu_page(__('One Click SSL', 'one-click-ssl'), __('One Click SSL', 'one-click-ssl'), 'activate_plugins', 'one-click-ssl', array($this, 'admin'), null, null);	
				}
			}
			
			add_action('admin_head-' . $this -> ocssl_menu, array($this, 'admin_head_ocssl'));
			
			$this -> add_dashboard();
		}
		
		function admin_head_ocssl() {		
			if (is_multisite() && is_network_admin()) {
				add_meta_box('submitdiv', __('Save Settings', 'one-click-ssl'), array($this, "settings_submit"), $this -> ocssl_menu, 'side', 'core');
				add_meta_box('generaldiv', __('General Settings', 'one-click-ssl'), array($this, "settings_network_general"), $this -> ocssl_menu, 'normal', 'core');
				add_meta_box('pluginsdiv', __('Recommended Plugin', 'one-click-ssl'), array($this, 'settings_plugins'), $this -> ocssl_menu, 'side', 'core');
			} else {			
				add_meta_box('submitdiv', __('Save Settings', 'one-click-ssl'), array($this, "settings_submit"), $this -> ocssl_menu, 'side', 'core');
				add_meta_box('generaldiv', __('General Settings', 'one-click-ssl'), array($this, "settings_general"), $this -> ocssl_menu, 'normal', 'core');
				add_meta_box('scannerdiv', __('Insecure Resources Scanner', 'one-click-ssl'), array($this, "settings_scanner"), $this -> ocssl_menu, 'normal', 'core');
				add_meta_box('pluginsdiv', __('Recommended Plugin', 'one-click-ssl'), array($this, 'settings_plugins'), $this -> ocssl_menu, 'side', 'core');
			}
			
			do_action('do_meta_boxes', $this -> ocssl_menu, 'normal');
			do_action('do_meta_boxes', $this -> ocssl_menu, 'side');
		}
		
		function add_dashboard() {
			add_dashboard_page(sprintf('One Click SSL %s', $this -> plugin_version), sprintf('One Click SSL %s', $this -> plugin_version), 'read', 'one-click-ssl-setup', array($this, 'admin_setup'));
			remove_submenu_page('index.php', 'one-click-ssl-setup');
		}
		
		function settings_submit() {
			include($this -> plugin_path . 'views' . DS . 'settings-submit.php');
		}
		
		function settings_general() {
			include($this -> plugin_path . 'views' . DS . 'settings-general.php');
		}
		
		function settings_scanner() {
			include($this -> plugin_path . 'views' . DS . 'settings-scanner.php');
		}
		
		function settings_plugins() {
			include($this -> plugin_path . 'views' . DS . 'settings-plugins.php');
		}
		
		function settings_network_general() {
			include($this -> plugin_path . 'views' . DS . 'settings-network-general.php');
		}
		
		function admin() {		
			$ocssl_toolsmenu = get_option('ocssl_toolsmenu');
										
			if (!empty($_POST)) {				
				update_option('ocssl', 0);
				update_option('ocssl_nonsslredirect', 0);
				update_option('ocssl_toolsmenu', 0);
				
				foreach ($_POST as $pkey => $pval) {
					update_option(esc_html($pkey), esc_html($pval));
				}
				
				// Redirect if the menu location changed
				if ((empty($ocssl_toolsmenu) && !empty($_POST['ocssl_toolsmenu'])) || 
					(!empty($ocssl_toolsmenu) && empty($_POST['ocssl_toolsmenu']))) {
					wp_redirect(admin_url('admin.php?page=one-click-ssl'));
					exit();
				}
				
				wp_cache_flush();
				$this -> check_ssl();
				
				$this -> render_message(__('Settings have been saved', 'one-click-ssl'));
				do_action('ocssl_settings_saved', $_POST);
			}
			
			include($this -> plugin_path . 'views' . DS . 'settings.php');
		}
		
		function admin_network() {
			if (!empty($_POST)) {
				update_site_option('ocssl_global', 0);
				
				foreach ($_POST as $pkey => $pval) {
					update_site_option(esc_html($pkey), esc_html($pval));
				}
				
				wp_cache_flush();
				$this -> check_network_ssl();
				
				$this -> render_message(__('Settings have been saved', 'one-click-ssl'));
				do_action('ocssl_network_settings_saved', $_POST);
			}
			
			include($this -> plugin_path . 'views' . DS . 'settings-network.php');
		}
		
		function admin_setup() {
			delete_option('ocssl_activation_redirect');
			include($this -> plugin_path . 'views' . DS . 'setup.php');
		}
		
		function admin_enqueue_scripts() {
			wp_enqueue_style('font-awesome', $this -> plugin_url . 'css/font-awesome.min.css', false, '4.7.0', "all");
			wp_enqueue_style('one-click-ssl', $this -> plugin_url . 'css/one-click-ssl.css', array('font-awesome'), $this -> plugin_version, "all");
			
			if (!empty($_GET['page']) && ($_GET['page'] == 'one-click-ssl-setup' || $_GET['page'] == 'one-click-ssl')) {			
				wp_enqueue_style('animate', $this -> plugin_url . 'css/animate.css', false, '1.0', "all");
				
				wp_enqueue_script('jquery');
				wp_enqueue_script('common');
				wp_enqueue_script('wp-lists');
				wp_enqueue_script('postbox');
				wp_enqueue_script('plugin-install');
				wp_register_script('one-click-ssl', $this -> plugin_url . 'js/one-click-ssl.js', array('jquery'), $this -> plugin_version, true);
				
				$translation_array = array(
					'is_ssl'					=>	is_ssl(),
					'settings_url'				=>	((is_multisite()) ? network_admin_url('admin.php?page=one-click-ssl') : admin_url('admin.php?page=one-click-ssl')),
					'settingswarning' 			=> 	__('By turning on SSL, your server must support SSL (https://) or this could make your website inaccessible.' . "\r\n\r\n" . 'Upon clicking OK, you will be asked to login to your WordPress dashboard again if the protocol changes.' . "\r\n\r\n" . 'If you are uncertain, click Cancel below.', 'one-click-ssl'),
				);
				
				wp_localize_script('one-click-ssl', 'ocssl', $translation_array);
				wp_enqueue_script('one-click-ssl');
			}
		}
		
		function admin_notices() {
			
		}
		
		function plugin_action_links($actions = null, $plugin_file = null, $plugin_data = null, $context = null) {			
			if (!empty($plugin_file) && $plugin_file == $this -> plugin_base) {
				if (is_multisite() && is_network_admin()) {
					$actions[] = '<a href="' . network_admin_url('admin.php?page=one-click-ssl') . '">' . __('Settings', 'one-click-ssl') . '</a>';
					$actions = apply_filters('ocssl_plugin_actions', $actions);
				} else {
					$actions[] = '<a href="' . admin_url('admin.php?page=one-click-ssl') . '">' . __('Settings', 'one-click-ssl') . '</a>';
					$actions = apply_filters('ocssl_plugin_actions', $actions);
				}
			}
			
			return $actions;
		}
		
		function render_message($message = null, $type = 'success', $dismissable = true) {
			if (!empty($message)) {
				?>
				
				<div class="notice notice-<?php echo $type; ?> <?php echo (!empty($dismissable)) ? 'is-dismissable' : ''; ?>">
			        <p>
				        <?php
					        
					        
					    switch ($type) {
						    case 'error'			:
						    	echo '<i class="fa fa-times fa-fw"></i>';
						    	break;
						    case 'warning'			:
						    	echo '<i class="fa fa-exclamation-triangle fa-fw"></i>';
						    	break;
						    case 'success'			:
						    default 				:
						    	echo '<i class="fa fa-check fa-fw"></i>';
						    	break;
					    }    
				        
				        ?>
				        <?php echo $message; ?>
				    </p>
			    </div>
				
				<?php
			}
		}
		
		function make_request($url = null) {
			global $ocssl_http_code;
			
			if (empty($url)) {
				$url = home_url(false, 'https');	
			}
			
			$timeout = 5;
			$body = false;
			
			if (function_exists('curl_init')) {								
				$ch = curl_init($url);
				curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)");
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
				curl_setopt($ch, CURLOPT_VERBOSE, false);
				curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
				curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, true);
				curl_setopt($ch, CURLOPT_HEADER, true);
				curl_setopt($ch, CURLOPT_POST, true);
				curl_setopt($ch, CURLOPT_POSTFIELDS, array('ocssl_check' => true));
				curl_setopt($ch, CURLOPT_URL, $url);
				curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
				$data = curl_exec($ch);
	
				$header_size = curl_getinfo($ch, CURLINFO_HEADER_SIZE);
				$http_code = intval(curl_getinfo($ch, CURLINFO_HTTP_CODE));
				$ocssl_http_code = $http_code;
				$body = substr($data, $header_size);
			} else {
				$args = array(
					'timeout'     	=> 	$timeout,
					'httpversion' 	=> 	'1.1',
					'sslverify'   	=> 	true,
					'body'			=>	array('ocssl_check' => true),
				);
				
				$response = wp_remote_post($url, $args);
				
				if (!is_wp_error($response)) {
					$ocssl_http_code = $response['response']['code'];
					if (!empty($response['response']['code']) && $response['response']['code'] == 200) {
						$body = $response['body'];
					}
				}
			}
			
			$response = array(
				'code'			=>	$ocssl_http_code,
				'body'			=>	$body,
			);
			
			return $response;
		}
		
		function has_ssl_support() {	
			global $ocssl_http_code;
					
			$has_ssl = false;
			$url = home_url(false, 'https');
			
			if ($response = $this -> make_request($url)) {
				if (!empty($response['code']) && $response['code'] == 200) {
					$has_ssl = true;
				}	
			}
	
			return apply_filters('ocssl_has_ssl', $has_ssl);
		}
		
		function check_ssl() {			
			
			// Don't do redirects if the SSL support is being checked
			if (!empty($_POST['ocssl_check'])) {
				return;
			}
											
			// Is SSL turned on ?
			$ocssl = get_option('ocssl');
			
			$ocssl_nonsslredirect = get_option('ocssl_nonsslredirect');	
			$nonssl = (!empty($ocssl_nonsslredirect)) ? true : false;
				
			if (!empty($ocssl)) {
				$ocssl_areas = get_option('ocssl_areas');
				$doredirect = false;
				$redirecturl = "https://" . $_SERVER["SERVER_NAME"] . $_SERVER["REQUEST_URI"];
				
				switch ($ocssl_areas) {
					case 'admin'				:
						// Only redirect the admin dashboard
						if ((is_admin() && !defined('DOING_AJAX')) || $GLOBALS['pagenow'] === 'wp-login.php') {
							$doredirect = true;
							$nonssl = false;
						}
						break;
					case 'front'				:
						// Only redirect when it's not the admin dashboard
						if (!is_admin() && $GLOBALS['pagenow'] !== 'wp-login.php') {							
							$doredirect = true;
							$nonssl = false;
						}
						break;
					case 'all'					:
					default 					:
						// Redirect everything, all pages and sections
						$doredirect = true;
						$nonssl = false;
						break;
				}
				
				if (!empty($doredirect)) {
					if (!is_ssl()) {
						// Go ahead and do the redirect
						$this -> redirect($redirecturl);
					}
				}	
			}
			
			// Redirect to non-SSL if we are on https:// but SSL setting is turned off
			if (!empty($nonssl) && $nonssl == true) {			
				if (is_ssl()) {					
					$redirecturl = "http://" . $_SERVER["SERVER_NAME"] . $_SERVER["REQUEST_URI"];
					$this -> redirect($redirecturl);
				}
			}
		}
		
		function check_network_ssl() {											
			// Is SSL turned on ?
			$ocssl_global = get_site_option('ocssl_global');
				
			if (!empty($ocssl_global)) {
				$redirecturl = "https://" . $_SERVER["SERVER_NAME"] . $_SERVER["REQUEST_URI"];
				
				if (!is_ssl()) {
					// Go ahead and do the redirect
					$this -> redirect($redirecturl);
				}
			}
		}
		
		function redirect($redirecturl = null) {
			if (!empty($redirecturl)) {
				if (headers_sent()) {					
					?>
						
					<script type="text/javascript">
					document.location = "<?php echo esc_attr(stripslashes($redirecturl)); ?>";
					</script>
					
					<?php
				} else {
					wp_redirect($redirecturl, "301");
					exit();
				}
			}
		}
	
		function replace_https($value = null) {	
			if (!empty($value)) {
				$ocssl = get_option('ocssl');
				if (!empty($ocssl)) {	
					if (is_ssl()) {
						if (!is_array($value) && !is_object($value)) {
							$value = preg_replace('|/+$|', '', $value);
							$value = preg_replace('|http://|', 'https://', $value);
						}		
					}
				}
			}
		
			return apply_filters('ocssl_replace_https', $value);
		}
		
		function ajax_check_ssl_support() {
			define('DOING_AJAX', true);
			define('SHORTINIT', true);
			
			ob_start();
			
			global $ocssl_http_code;
			
			if ($this -> has_ssl_support()) {
				$response = array('success' => true, 'http_code' => $ocssl_http_code);
			} else {
				$error = sprintf('<i class="fa fa-times"></i> ' . __('SSL is not supported. Website returned response code %s over SSL. Please ask your hosting provider to check for you.', 'one-click-ssl'), '<strong>' . $ocssl_http_code . '</strong>');
				$response = array('success' => false, 'http_code' => $ocssl_http_code, 'error' => $error);
			}
			
			$process = ob_get_clean();
			echo json_encode($response);
			
			exit();
			die();
		}
		
		function ajax_enable_ssl() {
			define('DOING_AJAX', true);
			define('SHORTINIT', true);
			
			if (is_multisite()) {
				update_site_option('ocssl_global', 1);	
			} else {
				update_option('ocssl', 1);
			}
				
			wp_cache_flush();
			
			exit();
			die();
		}
		
		function ajax_scan() {
			define('DOING_AJAX', true);
			define('SHORTINIT', true);
			
			ob_start();
			
			$success = false;
			$insecure = false;
			
			$url = home_url('/', 'https');
			if (!empty($_POST['scanurl'])) {
				$scanurl = esc_html($_POST['scanurl']);
				$url .= ltrim($scanurl, '/');
			}
			
			if ($response = $this -> make_request($url)) {				
				if (!empty($response) && $response['code'] == 200) {					
					$pattern = '/<[script|link|base|img|form][^>]*[href|src|action]=[\'"]\K(http:\/\/[^\'"]+)[\'"]/i';
					if (preg_match_all($pattern, $response['body'], $matches)) {
						if (!empty($matches[1])) {
							$success = false;
							$insecure = $matches[1];
							
							$output = '<div class="alert alert-warning">';
							$output .= '<i class="fa fa-exclamation-triangle fa-fw"></i> ' . sprintf(__('%s Insecure resources found on the URL, make them https:// for SSL to validate', 'one-click-ssl'), count($matches[1]));
							
							$output .= '<ul>';
							foreach ($matches[1] as $insecure_url) {
								$output .= '<li>' . $insecure_url . '</li>';
							}
							$output .= '</ul>';
							
							$output .= '</div>';
						} else {
							$success = true;
							$insecure = false;
							
							$output = '<div class="alert-success">';
							$output .= '<i class="fa fa-check fa-fw"></i> ' . __('No insecure resources found, SSL will validate!', 'one-click-ssl');
							$output .= '</div>';
						}
					} else {
						$success = false;
						$insecure = false;
						$output = '<div class="alert alert-danger"><i class="fa fa-times fa-fw"></i> ' . __('No elements found on URL - Code %s', 'one-click-ssl') . '</div>';
					}
				} else {
					$success = false;
					$insecure = false;
					$output = '<div class="alert alert-danger"><i class="fa fa-times fa-fw"></i> ' . sprintf(__('URL could not be loaded - Code %s', 'one-click-ssl'), $response['code']) . '</div>';
				}
			} else {
				$success = false;
				$insecure = false;
				$output = '<div class="alert alert-danger"><i class="fa fa-times fa-fw"></i> ' . __('Request failed, please try again.', 'one-click-ssl') . '</div>';
			}
			
			$reply = array(
				'success'			=>	$success,
				'insecure'			=>	$insecure,
				'output'			=>	$output
			);
			
			$process = ob_get_clean();
			echo json_encode($reply);
			
			exit();
			die();
		}
		
		function filter_buffer($buffer = null) {
			$buffer = $this -> replace_insecure_links($buffer);
			return $buffer;
		}
		
		function start_buffer() {
			// Check if SSL is enabled and current protocol is SSL
			$ocssl = get_option('ocssl');
			if (!empty($ocssl) && is_ssl()) {
				$this -> build_url_list();
				ob_start(array($this, "filter_buffer"));
			}
		}
		
		function stop_buffer() {
			// Check if SSL is enabled and current protocol is SSL
			$ocssl = get_option('ocssl');
			if (!empty($ocssl) && is_ssl()) {
				if (ob_get_length()) {
					ob_end_flush();
				}
			}
		}
		
		function build_url_list() {
			$home = str_replace("https://", "http://" , get_option('home'));
			$home_no_www  = str_replace("://www.", "://", $home);
			$home_yes_www = str_replace("://", "://www.", $home_no_www);
			$escaped_home = str_replace("/", "\/", $home);
			
			$this -> http_urls = array(
				$home_yes_www,
				$home_no_www,
				$escaped_home,
				"src='http://",
				'src="http://',
			);
		}
		
		function replace_insecure_links($str = null) {			
			$search_array = apply_filters('ocssl_replace_search_list', $this -> http_urls);
			$ssl_array = str_replace(array("http://", "http:\/\/"), array("https://", "https:\/\/"), $search_array);
			$str = str_replace($search_array, $ssl_array, $str);
			
			$patterns = array(
				'/url\([\'"]?\K(http:\/\/)(?=[^)]+)/i',
				'/<link .*?href=[\'"]\K(http:\/\/)(?=[^\'"]+)/i',
				'/<meta property="og:image" .*?content=[\'"]\K(http:\/\/)(?=[^\'"]+)/i',
				'/<form [^>]*?action=[\'"]\K(http:\/\/)(?=[^\'"]+)/i',
				'/<(script|link|base|img|form)[^>]*(href|src|action)=[\'"]\K(http:\/\/)(?=[^\'"]+)/i',
			);
			
			$str = preg_replace($patterns, 'https://', $str);
			
			global $ocssl_bodydata;
			if (empty($ocssl_bodydata)) {
				$str = str_replace("<body ", "<body data-ocssl='1' ", $str);
				$ocssl_bodydata = true;
			}
			
			return apply_filters("ocssl_replace_output", $str);
		}
		
		function debug($var = array()) {
			echo '<pre>' . print_r($var, true) . '</pre>';
		}
	}
	
	$ocssl = new OCSSL();
	
	register_activation_hook(__FILE__, array($ocssl, 'activation_hook'));
	
	add_action('admin_init', array($ocssl, 'start_buffer'), 10, 1);
	add_action('init', array($ocssl, 'start_buffer'), 10, 1);
	add_action('shutdown', array($ocssl, 'stop_buffer'), 10, 1);
	
	add_action('init', array($ocssl, 'init_textdomain'), 10, 1);
	add_action('admin_init', array($ocssl, 'custom_redirect'), 10, 1);
	add_action('admin_head', array($ocssl, 'admin_head'), 10, 1);
	
	if (is_multisite()) {
		add_action('network_admin_menu', array($ocssl, 'admin_menu'), 10, 1);
	} else {
		add_action('admin_menu', array($ocssl, 'admin_menu'), 10, 1);
	}
		
	add_action('admin_enqueue_scripts', array($ocssl, 'admin_enqueue_scripts'), 10, 1);
	add_action('admin_notices', array($ocssl, 'admin_notices'), 10, 1);
	
	if (is_multisite()) {
		add_action('wp_loaded', array($ocssl, 'check_network_ssl'), 10, 1);	
	} else {
		add_action('wp_loaded', array($ocssl, 'check_ssl'), 10, 1);
	}
	
	if (is_multisite()) {
		add_filter('network_admin_plugin_action_links', array($ocssl, 'plugin_action_links'), 10, 4);
	} else {
		add_filter('plugin_action_links', array($ocssl, 'plugin_action_links'), 10, 4);
	}
	
	add_filter('upload_dir', array($ocssl, 'replace_https'));
	add_filter('option_siteurl', array($ocssl, 'replace_https'));
	add_filter('option_home', array($ocssl, 'replace_https'));
	add_filter('option_url', array($ocssl, 'replace_https'));
	add_filter('option_wpurl', array($ocssl, 'replace_https'));
	add_filter('option_stylesheet_url', array($ocssl, 'replace_https'));
	add_filter('option_template_url', array($ocssl, 'replace_https'));
	add_filter('wp_get_attachment_url', array($ocssl, 'replace_https'));
	add_filter('widget_text', array($ocssl, 'replace_https'));
	add_filter('login_url', array($ocssl, 'replace_https'));
	add_filter('language_attributes', array($ocssl, 'replace_https'));
	
	// Ajax Actions
	add_action('wp_ajax_ocssl_check_ssl_support', array($ocssl, 'ajax_check_ssl_support'));
	add_action('wp_ajax_ocssl_enable_ssl', array($ocssl, 'ajax_enable_ssl'));
	add_action('wp_ajax_ocssl_scan', array($ocssl, 'ajax_scan'));
}